Class: Aws::ARCRegionswitch::Types::AuroraServerlessScalingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Configuration for Amazon Aurora Serverless scaling used in a Region switch plan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cross_account_roleString

The cross account role for the configuration.

Returns:

  • (String)


398
399
400
401
402
403
404
405
406
407
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398

class AuroraServerlessScalingConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :global_cluster_identifier,
  :region_database_cluster_arns,
  :target_percent)
  SENSITIVE = []
  include Aws::Structure
end

#external_idString

The external ID (secret key) for the configuration.

Returns:

  • (String)


398
399
400
401
402
403
404
405
406
407
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398

class AuroraServerlessScalingConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :global_cluster_identifier,
  :region_database_cluster_arns,
  :target_percent)
  SENSITIVE = []
  include Aws::Structure
end

#global_cluster_identifierString

The global cluster identifier for a global database.

Returns:

  • (String)


398
399
400
401
402
403
404
405
406
407
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398

class AuroraServerlessScalingConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :global_cluster_identifier,
  :region_database_cluster_arns,
  :target_percent)
  SENSITIVE = []
  include Aws::Structure
end

#region_database_cluster_arnsHash<String,String>

Per-Region configuration that maps each Region to the Aurora database cluster ARN for scaling.

Returns:

  • (Hash<String,String>)


398
399
400
401
402
403
404
405
406
407
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398

class AuroraServerlessScalingConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :global_cluster_identifier,
  :region_database_cluster_arns,
  :target_percent)
  SENSITIVE = []
  include Aws::Structure
end

#target_percentInteger

The target capacity percentage for Aurora Serverless scaling.

Returns:

  • (Integer)


398
399
400
401
402
403
404
405
406
407
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398

class AuroraServerlessScalingConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :global_cluster_identifier,
  :region_database_cluster_arns,
  :target_percent)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_minutesInteger

The timeout value specified for the configuration.

Returns:

  • (Integer)


398
399
400
401
402
403
404
405
406
407
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398

class AuroraServerlessScalingConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :global_cluster_identifier,
  :region_database_cluster_arns,
  :target_percent)
  SENSITIVE = []
  include Aws::Structure
end