Class: Aws::ARCRegionswitch::Types::CreatePlanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::CreatePlanRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_alarms ⇒ Hash<String,Types::AssociatedAlarm>
The alarms associated with a Region switch plan.
-
#description ⇒ String
The description of a Region switch plan.
-
#execution_role ⇒ String
An execution role is a way to categorize a Region switch plan.
-
#name ⇒ String
The name of a Region switch plan.
-
#primary_region ⇒ String
The primary Amazon Web Services Region for the application.
-
#recovery_approach ⇒ String
The recovery approach for a Region switch plan, which can be active/active (activeActive) or active/passive (activePassive).
-
#recovery_time_objective_minutes ⇒ Integer
Optionally, you can specify an recovery time objective for a Region switch plan, in minutes.
-
#regions ⇒ Array<String>
An array that specifies the Amazon Web Services Regions for a Region switch plan.
-
#report_configuration ⇒ Types::ReportConfiguration
Configuration for automatic report generation for plan executions.
-
#tags ⇒ Hash<String,String>
The tags to apply to the Region switch plan.
-
#triggers ⇒ Array<Types::Trigger>
The triggers associated with a Region switch plan.
-
#workflows ⇒ Array<Types::Workflow>
An array of workflows included in a Region switch plan.
Instance Attribute Details
#associated_alarms ⇒ Hash<String,Types::AssociatedAlarm>
The alarms associated with a Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of a Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
An execution role is a way to categorize a Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of a Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#primary_region ⇒ String
The primary Amazon Web Services Region for the application. This is the Region where the application normally runs before any Region switch occurs.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#recovery_approach ⇒ String
The recovery approach for a Region switch plan, which can be active/active (activeActive) or active/passive (activePassive).
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#recovery_time_objective_minutes ⇒ Integer
Optionally, you can specify an recovery time objective for a Region switch plan, in minutes.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
An array that specifies the Amazon Web Services Regions for a Region switch plan. Specify two Regions.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#report_configuration ⇒ Types::ReportConfiguration
Configuration for automatic report generation for plan executions. When configured, Region switch automatically generates a report after each plan execution that includes execution events, plan configuration, and CloudWatch alarm states.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to the Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#triggers ⇒ Array<Types::Trigger>
The triggers associated with a Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |
#workflows ⇒ Array<Types::Workflow>
An array of workflows included in a Region switch plan.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 493 class CreatePlanRequest < Struct.new( :description, :workflows, :execution_role, :recovery_time_objective_minutes, :associated_alarms, :triggers, :report_configuration, :name, :regions, :recovery_approach, :primary_region, :tags) SENSITIVE = [] include Aws::Structure end |