Class: Aws::ARCRegionswitch::Types::CustomActionLambdaConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Configuration for Amazon Web Services Lambda functions that perform custom actions during a Region switch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambdasArray<Types::Lambdas>

The Amazon Web Services Lambda functions for the execution block.

Returns:



468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 468

class CustomActionLambdaConfiguration < Struct.new(
  :timeout_minutes,
  :lambdas,
  :retry_interval_minutes,
  :region_to_run,
  :ungraceful)
  SENSITIVE = []
  include Aws::Structure
end

#region_to_runString

The Amazon Web Services Region for the function to run in. For recovery workflows use ‘activatingRegion` or `deactivatingRegion`. For post-recovery workflows, use `activeRegion` (the Region with customer traffic) or `inactiveRegion` (the Region with no customer traffic).

Returns:

  • (String)


468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 468

class CustomActionLambdaConfiguration < Struct.new(
  :timeout_minutes,
  :lambdas,
  :retry_interval_minutes,
  :region_to_run,
  :ungraceful)
  SENSITIVE = []
  include Aws::Structure
end

#retry_interval_minutesFloat

The retry interval specified.

Returns:

  • (Float)


468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 468

class CustomActionLambdaConfiguration < Struct.new(
  :timeout_minutes,
  :lambdas,
  :retry_interval_minutes,
  :region_to_run,
  :ungraceful)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_minutesInteger

The timeout value specified for the configuration.

Returns:

  • (Integer)


468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 468

class CustomActionLambdaConfiguration < Struct.new(
  :timeout_minutes,
  :lambdas,
  :retry_interval_minutes,
  :region_to_run,
  :ungraceful)
  SENSITIVE = []
  include Aws::Structure
end

#ungracefulTypes::LambdaUngraceful

The settings for ungraceful execution.



468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 468

class CustomActionLambdaConfiguration < Struct.new(
  :timeout_minutes,
  :lambdas,
  :retry_interval_minutes,
  :region_to_run,
  :ungraceful)
  SENSITIVE = []
  include Aws::Structure
end