Class: Aws::ARCRegionswitch::Types::EcsCapacityIncreaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::EcsCapacityIncreaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
The configuration for an Amazon Web Services ECS capacity increase.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_monitoring_approach ⇒ String
The monitoring approach specified for the configuration, for example, ‘Most_Recent`.
-
#services ⇒ Array<Types::Service>
The services specified for the configuration.
-
#target_percent ⇒ Integer
The target percentage specified for the configuration.
-
#timeout_minutes ⇒ Integer
The timeout value specified for the configuration.
-
#ungraceful ⇒ Types::EcsUngraceful
The settings for ungraceful execution.
Instance Attribute Details
#capacity_monitoring_approach ⇒ String
The monitoring approach specified for the configuration, for example, ‘Most_Recent`.
635 636 637 638 639 640 641 642 643 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 635 class EcsCapacityIncreaseConfiguration < Struct.new( :timeout_minutes, :services, :ungraceful, :target_percent, :capacity_monitoring_approach) SENSITIVE = [] include Aws::Structure end |
#services ⇒ Array<Types::Service>
The services specified for the configuration.
635 636 637 638 639 640 641 642 643 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 635 class EcsCapacityIncreaseConfiguration < Struct.new( :timeout_minutes, :services, :ungraceful, :target_percent, :capacity_monitoring_approach) SENSITIVE = [] include Aws::Structure end |
#target_percent ⇒ Integer
The target percentage specified for the configuration. The default is 100.
635 636 637 638 639 640 641 642 643 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 635 class EcsCapacityIncreaseConfiguration < Struct.new( :timeout_minutes, :services, :ungraceful, :target_percent, :capacity_monitoring_approach) SENSITIVE = [] include Aws::Structure end |
#timeout_minutes ⇒ Integer
The timeout value specified for the configuration.
635 636 637 638 639 640 641 642 643 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 635 class EcsCapacityIncreaseConfiguration < Struct.new( :timeout_minutes, :services, :ungraceful, :target_percent, :capacity_monitoring_approach) SENSITIVE = [] include Aws::Structure end |
#ungraceful ⇒ Types::EcsUngraceful
The settings for ungraceful execution.
635 636 637 638 639 640 641 642 643 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 635 class EcsCapacityIncreaseConfiguration < Struct.new( :timeout_minutes, :services, :ungraceful, :target_percent, :capacity_monitoring_approach) SENSITIVE = [] include Aws::Structure end |