Class: Aws::ARCRegionswitch::Types::GeneratedReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::GeneratedReport
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Information about a generated execution report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#report_generation_time ⇒ Time
The timestamp when the report was generated.
-
#report_output ⇒ Types::ReportOutput
The output location or cause of a failure in report generation.
Instance Attribute Details
#report_generation_time ⇒ Time
The timestamp when the report was generated.
1080 1081 1082 1083 1084 1085 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1080 class GeneratedReport < Struct.new( :report_generation_time, :report_output) SENSITIVE = [] include Aws::Structure end |
#report_output ⇒ Types::ReportOutput
The output location or cause of a failure in report generation.
1080 1081 1082 1083 1084 1085 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1080 class GeneratedReport < Struct.new( :report_generation_time, :report_output) SENSITIVE = [] include Aws::Structure end |