Class: Aws::ARCRegionswitch::Types::GetPlanEvaluationStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The number of objects that you want to return with this call.

Returns:

  • (Integer)


1005
1006
1007
1008
1009
1010
1011
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1005

class GetPlanEvaluationStatusRequest < Struct.new(
  :plan_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specifies that you want to receive the next page of results. Valid only if you received a ‘nextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘nextToken` response to request the next page of results.

Returns:

  • (String)


1005
1006
1007
1008
1009
1010
1011
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1005

class GetPlanEvaluationStatusRequest < Struct.new(
  :plan_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#plan_arnString

The Amazon Resource Name (ARN) of the Region switch plan to retrieve evaluation status for.

Returns:

  • (String)


1005
1006
1007
1008
1009
1010
1011
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1005

class GetPlanEvaluationStatusRequest < Struct.new(
  :plan_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end