Class: Aws::ARCRegionswitch::Types::GetPlanExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_idString

The execution identifier of a plan execution.

Returns:

  • (String)


1083
1084
1085
1086
1087
1088
1089
1090
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083

class GetPlanExecutionRequest < Struct.new(
  :plan_arn,
  :execution_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The number of objects that you want to return with this call.

Returns:

  • (Integer)


1083
1084
1085
1086
1087
1088
1089
1090
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083

class GetPlanExecutionRequest < Struct.new(
  :plan_arn,
  :execution_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specifies that you want to receive the next page of results. Valid only if you received a ‘nextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘nextToken` response to request the next page of results.

Returns:

  • (String)


1083
1084
1085
1086
1087
1088
1089
1090
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083

class GetPlanExecutionRequest < Struct.new(
  :plan_arn,
  :execution_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#plan_arnString

The Amazon Resource Name (ARN) of the plan with the execution to retrieve.

Returns:

  • (String)


1083
1084
1085
1086
1087
1088
1089
1090
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083

class GetPlanExecutionRequest < Struct.new(
  :plan_arn,
  :execution_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end