Class: Aws::ARCRegionswitch::Types::GetPlanExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actual_recovery_timeString

The actual recovery time that Region switch calculates for a plan execution. Actual recovery time includes the time for the plan to run added to the time elapsed until the application health alarms that you've specified are healthy again.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#commentString

A comment included on the plan execution.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time (UTC) when the plan execution ended.

Returns:

  • (Time)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#execution_actionString

The plan execution action. Valid values are activate, to activate an Amazon Web Services Region, or deactivate, to deactivate a Region.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#execution_idString

The execution identifier of a plan execution.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#execution_regionString

The Amazon Web Services Region for a plan execution.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#execution_stateString

The plan execution state. Provides the state of a plan execution, for example, In Progress or Paused by Operator.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#generated_report_detailsArray<Types::GeneratedReport>

Information about the location of a generated report, or the cause of its failure.

Returns:



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

The plan execution mode. Valid values are graceful, for graceful executions, or ungraceful, for ungraceful executions.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specifies that you want to receive the next page of results. Valid only if you received a nextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call's nextToken response to request the next page of results.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#planTypes::Plan

The details of the Region switch plan.

Returns:



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#plan_arnString

The Amazon Resource Name (ARN) of the plan.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_execution_idString

The unique identifier of the most recent recovery execution. Required when starting a post-recovery execution.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time (UTC) when the plan execution started.

Returns:

  • (Time)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_statesArray<Types::StepState>

The states of the steps in the plan execution.

Returns:



1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the plan execution was last updated.

Returns:

  • (Time)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version for the plan.

Returns:

  • (String)


1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1276

class GetPlanExecutionResponse < Struct.new(
  :plan_arn,
  :execution_id,
  :version,
  :updated_at,
  :comment,
  :start_time,
  :end_time,
  :mode,
  :execution_state,
  :execution_action,
  :execution_region,
  :recovery_execution_id,
  :step_states,
  :plan,
  :actual_recovery_time,
  :generated_report_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end