Class: Aws::ARCRegionswitch::Types::GetPlanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::GetPlanResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#plan ⇒ Types::Plan
The detailed information about the requested Region switch plan.
Instance Attribute Details
#plan ⇒ Types::Plan
The detailed information about the requested Region switch plan.
1239 1240 1241 1242 1243 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1239 class GetPlanResponse < Struct.new( :plan) SENSITIVE = [] include Aws::Structure end |