Class: Aws::ARCRegionswitch::Types::LambdaEventSourceMappingUngraceful

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Specifies whether to skip enabling or disabling an event source mapping during an ungraceful execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#behaviorString

Set to ‘skip` to skip executing this event source mapping step during an ungraceful execution.

Returns:

  • (String)


1438
1439
1440
1441
1442
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1438

class LambdaEventSourceMappingUngraceful < Struct.new(
  :behavior)
  SENSITIVE = []
  include Aws::Structure
end