Class: Aws::ARCRegionswitch::Types::LambdaUngraceful
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::LambdaUngraceful
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Configuration for handling failures when invoking Lambda functions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#behavior ⇒ String
The ungraceful behavior for a Lambda function, which must be set to
skip.
Instance Attribute Details
#behavior ⇒ String
The ungraceful behavior for a Lambda function, which must be set to
skip.
1580 1581 1582 1583 1584 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1580 class LambdaUngraceful < Struct.new( :behavior) SENSITIVE = [] include Aws::Structure end |