Class: Aws::ARCRegionswitch::Types::MinimalWorkflow
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::MinimalWorkflow
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
A simplified representation of a workflow in a Region switch plan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action for a minimal workflow, which can be Activate or Deactivate.
-
#name ⇒ String
The name for a minimal workflow.
Instance Attribute Details
#action ⇒ String
The action for a minimal workflow, which can be Activate or Deactivate.
1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1953 class MinimalWorkflow < Struct.new( :action, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name for a minimal workflow
1953 1954 1955 1956 1957 1958 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1953 class MinimalWorkflow < Struct.new( :action, :name) SENSITIVE = [] include Aws::Structure end |