Class: Aws::ARCRegionswitch::Types::NeptuneGlobalDatabaseConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Configuration for Amazon Neptune global databases used in a Region switch plan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#behaviorString

The behavior for a global database, that is, only allow switchover or also allow failover.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#cross_account_roleString

The cross account role for the configuration.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#external_idString

The external ID (secret key) for the configuration.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#global_cluster_identifierString

The global cluster identifier for a Neptune global database.

Returns:

  • (String)


1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#region_database_cluster_arnsHash<String,String>

The database cluster Amazon Resource Names (ARNs) for a Neptune global database.

Returns:

  • (Hash<String,String>)


1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_minutesInteger

The timeout value specified for the configuration.

Returns:

  • (Integer)


1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#ungracefulTypes::NeptuneUngraceful

The settings for ungraceful execution.



1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969

class NeptuneGlobalDatabaseConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :region_database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end