Class: Aws::ARCRegionswitch::Types::ReportConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Configuration for automatic report generation for plan executions. When configured, Region switch automatically generates a report after each plan execution that includes execution events, plan configuration, and CloudWatch alarm states.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#report_outputArray<Types::ReportOutputConfiguration>

The output configuration for the report.



2034
2035
2036
2037
2038
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2034

class ReportConfiguration < Struct.new(
  :report_output)
  SENSITIVE = []
  include Aws::Structure
end