Class: Aws::ARCRegionswitch::Types::S3ReportOutputConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::S3ReportOutputConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Configuration for delivering generated reports to an Amazon S3 bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_owner ⇒ String
The Amazon Web Services account ID that owns the S3 bucket.
-
#bucket_path ⇒ String
The S3 bucket name and optional prefix where reports are stored.
Instance Attribute Details
#bucket_owner ⇒ String
The Amazon Web Services account ID that owns the S3 bucket. Required to ensure the bucket is still owned by the same expected owner at generation time.
2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2431 class S3ReportOutputConfiguration < Struct.new( :bucket_path, :bucket_owner) SENSITIVE = [] include Aws::Structure end |
#bucket_path ⇒ String
The S3 bucket name and optional prefix where reports are stored. Format: bucket-name or bucket-name/prefix.
2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2431 class S3ReportOutputConfiguration < Struct.new( :bucket_path, :bucket_owner) SENSITIVE = [] include Aws::Structure end |