Class: Aws::ARCRegionswitch::Types::StartPlanExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::StartPlanExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time.
-
#comment ⇒ String
An optional comment explaining why the plan execution is being started.
-
#latest_version ⇒ String
A boolean value indicating whether to use the latest version of the plan.
-
#mode ⇒ String
The plan execution mode.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan to execute.
-
#recovery_execution_id ⇒ String
The execution identifier of the recovery execution that ran in the opposite region post-recovery is ran in.
-
#target_region ⇒ String
The Amazon Web Services Region to target with this execution.
Instance Attribute Details
#action ⇒ String
The action to perform. Valid values are activate (to shift traffic
to the target Region) or deactivate (to shift traffic away from
the target Region).
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request and returns the result of the original successful request. If you don't provide a client token, the service automatically generates one. For more information about idempotency, see Making retries safe with idempotent APIs.
A suitable default value is auto-generated. You should normally not need to pass this option.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
An optional comment explaining why the plan execution is being started.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#latest_version ⇒ String
A boolean value indicating whether to use the latest version of the plan. If set to false, you must specify a specific version.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The plan execution mode. Valid values are graceful, for starting
the execution in graceful mode, or ungraceful, for starting the
execution in ungraceful mode.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan to execute.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#recovery_execution_id ⇒ String
The execution identifier of the recovery execution that ran in the opposite region post-recovery is ran in. Required when starting a post-recovery execution.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |
#target_region ⇒ String
The Amazon Web Services Region to target with this execution. This is the Region that traffic will be shifted to or from, depending on the action.
2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2607 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id, :client_token) SENSITIVE = [] include Aws::Structure end |