Class: Aws::ARCRegionswitch::Types::StepState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Represents the state of a step in a plan execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The timestamp when a step endeded execution.

Returns:

  • (Time)


2448
2449
2450
2451
2452
2453
2454
2455
2456
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2448

class StepState < Struct.new(
  :name,
  :status,
  :start_time,
  :end_time,
  :step_mode)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a step in a workflow.

Returns:

  • (String)


2448
2449
2450
2451
2452
2453
2454
2455
2456
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2448

class StepState < Struct.new(
  :name,
  :status,
  :start_time,
  :end_time,
  :step_mode)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp when a step started execution.

Returns:

  • (Time)


2448
2449
2450
2451
2452
2453
2454
2455
2456
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2448

class StepState < Struct.new(
  :name,
  :status,
  :start_time,
  :end_time,
  :step_mode)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of a step in a workflow. For example, a status might be Completed or Pending Approval.

Returns:

  • (String)


2448
2449
2450
2451
2452
2453
2454
2455
2456
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2448

class StepState < Struct.new(
  :name,
  :status,
  :start_time,
  :end_time,
  :step_mode)
  SENSITIVE = []
  include Aws::Structure
end

#step_modeString

The mode for a step execution. The mode can be Graceful or Ungraceful.

Returns:

  • (String)


2448
2449
2450
2451
2452
2453
2454
2455
2456
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2448

class StepState < Struct.new(
  :name,
  :status,
  :start_time,
  :end_time,
  :step_mode)
  SENSITIVE = []
  include Aws::Structure
end