Class: Aws::ARCRegionswitch::Types::Trigger
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::Trigger
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Defines a condition that can automatically trigger the execution of a Region switch plan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform when the trigger fires.
-
#conditions ⇒ Array<Types::TriggerCondition>
The conditions that must be met for the trigger to fire.
-
#description ⇒ String
The description for a trigger.
-
#min_delay_minutes_between_executions ⇒ Integer
The minimum time, in minutes, that must elapse between automatic executions of the plan.
-
#target_region ⇒ String
The Amazon Web Services Region for a trigger.
Instance Attribute Details
#action ⇒ String
The action to perform when the trigger fires. Valid values include ‘activate` and `deactivate`.
2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class Trigger < Struct.new( :description, :target_region, :action, :conditions, :min_delay_minutes_between_executions) SENSITIVE = [] include Aws::Structure end |
#conditions ⇒ Array<Types::TriggerCondition>
The conditions that must be met for the trigger to fire.
2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class Trigger < Struct.new( :description, :target_region, :action, :conditions, :min_delay_minutes_between_executions) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for a trigger.
2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class Trigger < Struct.new( :description, :target_region, :action, :conditions, :min_delay_minutes_between_executions) SENSITIVE = [] include Aws::Structure end |
#min_delay_minutes_between_executions ⇒ Integer
The minimum time, in minutes, that must elapse between automatic executions of the plan.
2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class Trigger < Struct.new( :description, :target_region, :action, :conditions, :min_delay_minutes_between_executions) SENSITIVE = [] include Aws::Structure end |
#target_region ⇒ String
The Amazon Web Services Region for a trigger.
2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class Trigger < Struct.new( :description, :target_region, :action, :conditions, :min_delay_minutes_between_executions) SENSITIVE = [] include Aws::Structure end |