Class: Aws::ARCRegionswitch::Types::UpdatePlanExecutionStepRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::UpdatePlanExecutionStepRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_to_take ⇒ String
The updated action to take for the step.
-
#comment ⇒ String
An optional comment about the plan execution.
-
#execution_id ⇒ String
The unique identifier of the plan execution containing the step to update.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan containing the execution step to update.
-
#step_name ⇒ String
The name of the execution step to update.
Instance Attribute Details
#action_to_take ⇒ String
The updated action to take for the step. This can be used to skip or retry a step.
2616 2617 2618 2619 2620 2621 2622 2623 2624 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2616 class UpdatePlanExecutionStepRequest < Struct.new( :plan_arn, :execution_id, :comment, :step_name, :action_to_take) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
An optional comment about the plan execution.
2616 2617 2618 2619 2620 2621 2622 2623 2624 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2616 class UpdatePlanExecutionStepRequest < Struct.new( :plan_arn, :execution_id, :comment, :step_name, :action_to_take) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The unique identifier of the plan execution containing the step to update.
2616 2617 2618 2619 2620 2621 2622 2623 2624 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2616 class UpdatePlanExecutionStepRequest < Struct.new( :plan_arn, :execution_id, :comment, :step_name, :action_to_take) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan containing the execution step to update.
2616 2617 2618 2619 2620 2621 2622 2623 2624 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2616 class UpdatePlanExecutionStepRequest < Struct.new( :plan_arn, :execution_id, :comment, :step_name, :action_to_take) SENSITIVE = [] include Aws::Structure end |
#step_name ⇒ String
The name of the execution step to update.
2616 2617 2618 2619 2620 2621 2622 2623 2624 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2616 class UpdatePlanExecutionStepRequest < Struct.new( :plan_arn, :execution_id, :comment, :step_name, :action_to_take) SENSITIVE = [] include Aws::Structure end |