Class: Aws::ARCRegionswitch::Types::UpdatePlanRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the plan.

Returns:

  • (String)


2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#associated_alarmsHash<String,Types::AssociatedAlarm>

The updated CloudWatch alarms associated with the plan.

Returns:



2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The updated description for the Region switch plan.

Returns:

  • (String)


2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

The updated IAM role ARN that grants Region switch the permissions needed to execute the plan steps.

Returns:

  • (String)


2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_time_objective_minutesInteger

The updated target recovery time objective (RTO) in minutes for the plan.

Returns:

  • (Integer)


2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#report_configurationTypes::ReportConfiguration

The updated report configuration for the plan.



2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#triggersArray<Types::Trigger>

The updated conditions that can automatically trigger the execution of the plan.

Returns:



2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workflowsArray<Types::Workflow>

The updated workflows for the Region switch plan.

Returns:



2667
2668
2669
2670
2671
2672
2673
2674
2675
2676
2677
2678
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2667

class UpdatePlanRequest < Struct.new(
  :arn,
  :description,
  :workflows,
  :execution_role,
  :recovery_time_objective_minutes,
  :associated_alarms,
  :triggers,
  :report_configuration)
  SENSITIVE = []
  include Aws::Structure
end