Class: Aws::ARCRegionswitch::Types::Workflow

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Represents a workflow in a Region switch plan. A workflow defines a sequence of steps to execute during a Region switch.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stepsArray<Types::Step>

The steps that make up the workflow.

Returns:



2714
2715
2716
2717
2718
2719
2720
2721
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2714

class Workflow < Struct.new(
  :steps,
  :workflow_target_action,
  :workflow_target_region,
  :workflow_description)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_descriptionString

The description of the workflow.

Returns:

  • (String)


2714
2715
2716
2717
2718
2719
2720
2721
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2714

class Workflow < Struct.new(
  :steps,
  :workflow_target_action,
  :workflow_target_region,
  :workflow_description)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_target_actionString

The action that the workflow performs. Valid values include ‘activate` and `deactivate`.

Returns:

  • (String)


2714
2715
2716
2717
2718
2719
2720
2721
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2714

class Workflow < Struct.new(
  :steps,
  :workflow_target_action,
  :workflow_target_region,
  :workflow_description)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_target_regionString

The Amazon Web Services Region that the workflow targets.

Returns:

  • (String)


2714
2715
2716
2717
2718
2719
2720
2721
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2714

class Workflow < Struct.new(
  :steps,
  :workflow_target_action,
  :workflow_target_region,
  :workflow_description)
  SENSITIVE = []
  include Aws::Structure
end