Class: Aws::ARCRegionswitch::Waiters::PlanEvaluationStatusPassed
- Inherits:
-
Object
- Object
- Aws::ARCRegionswitch::Waiters::PlanEvaluationStatusPassed
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-arcregionswitch/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PlanEvaluationStatusPassed
constructor
A new instance of PlanEvaluationStatusPassed.
-
#wait(params = {}) ⇒ Types::GetPlanEvaluationStatusResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PlanEvaluationStatusPassed
Returns a new instance of PlanEvaluationStatusPassed.
85 86 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 85
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
123 124 125 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 123 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPlanEvaluationStatusResponse
Returns a response object which responds to the following methods:
- #plan_arn => String
- #last_evaluation_time => Time
- #last_evaluated_version => String
- #region => String
- #evaluation_state => String
- #warnings => Array<Types::ResourceWarning>
- #next_token => String
118 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 118
def wait: (
|