Class: Aws::ARCRegionswitch::Waiters::PlanExecutionCompleted
- Inherits:
-
Object
- Object
- Aws::ARCRegionswitch::Waiters::PlanExecutionCompleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-arcregionswitch/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PlanExecutionCompleted
constructor
A new instance of PlanExecutionCompleted.
-
#wait(params = {}) ⇒ Types::GetPlanExecutionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PlanExecutionCompleted
Returns a new instance of PlanExecutionCompleted.
135 136 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 135
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
185 186 187 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 185 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPlanExecutionResponse
Returns a response object which responds to the following methods:
- #plan_arn => String
- #execution_id => String
- #version => String
- #updated_at => Time
- #comment => String
- #start_time => Time
- #end_time => Time
- #mode => String
- #execution_state => String
- #execution_action => String
- #execution_region => String
- #recovery_execution_id => String
- #step_states => Array<Types::StepState>
- #plan => Types::Plan
- #actual_recovery_time => String
- #generated_report_details => Array<Types::GeneratedReport>
- #next_token => String
180 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 180
def wait: (
|