Class: Aws::ARCRegionswitch::Types::AuroraServerlessScalingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::AuroraServerlessScalingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Configuration for Amazon Aurora Serverless scaling used in a Region switch plan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cross_account_role ⇒ String
The cross account role for the configuration.
-
#external_id ⇒ String
The external ID (secret key) for the configuration.
-
#global_cluster_identifier ⇒ String
The global cluster identifier for a global database.
-
#region_database_cluster_arns ⇒ Hash<String,String>
Per-Region configuration that maps each Region to the Aurora database cluster ARN for scaling.
-
#target_percent ⇒ Integer
The target capacity percentage for Aurora Serverless scaling.
-
#timeout_minutes ⇒ Integer
The timeout value specified for the configuration.
Instance Attribute Details
#cross_account_role ⇒ String
The cross account role for the configuration.
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398 class AuroraServerlessScalingConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :global_cluster_identifier, :region_database_cluster_arns, :target_percent) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID (secret key) for the configuration.
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398 class AuroraServerlessScalingConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :global_cluster_identifier, :region_database_cluster_arns, :target_percent) SENSITIVE = [] include Aws::Structure end |
#global_cluster_identifier ⇒ String
The global cluster identifier for a global database.
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398 class AuroraServerlessScalingConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :global_cluster_identifier, :region_database_cluster_arns, :target_percent) SENSITIVE = [] include Aws::Structure end |
#region_database_cluster_arns ⇒ Hash<String,String>
Per-Region configuration that maps each Region to the Aurora database cluster ARN for scaling.
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398 class AuroraServerlessScalingConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :global_cluster_identifier, :region_database_cluster_arns, :target_percent) SENSITIVE = [] include Aws::Structure end |
#target_percent ⇒ Integer
The target capacity percentage for Aurora Serverless scaling.
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398 class AuroraServerlessScalingConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :global_cluster_identifier, :region_database_cluster_arns, :target_percent) SENSITIVE = [] include Aws::Structure end |
#timeout_minutes ⇒ Integer
The timeout value specified for the configuration.
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 398 class AuroraServerlessScalingConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :global_cluster_identifier, :region_database_cluster_arns, :target_percent) SENSITIVE = [] include Aws::Structure end |