Class: Aws::ARCRegionswitch::Types::GetPlanEvaluationStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::GetPlanEvaluationStatusRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The number of objects that you want to return with this call.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the Region switch plan to retrieve evaluation status for.
Instance Attribute Details
#max_results ⇒ Integer
The number of objects that you want to return with this call.
1005 1006 1007 1008 1009 1010 1011 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1005 class GetPlanEvaluationStatusRequest < Struct.new( :plan_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a ‘nextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘nextToken` response to request the next page of results.
1005 1006 1007 1008 1009 1010 1011 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1005 class GetPlanEvaluationStatusRequest < Struct.new( :plan_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the Region switch plan to retrieve evaluation status for.
1005 1006 1007 1008 1009 1010 1011 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1005 class GetPlanEvaluationStatusRequest < Struct.new( :plan_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |