Class: Aws::ARCRegionswitch::Types::GetPlanEvaluationStatusResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::GetPlanEvaluationStatusResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#evaluation_state ⇒ String
The evaluation state for the plan.
-
#last_evaluated_version ⇒ String
The version of the last evaluation of the plan.
-
#last_evaluation_time ⇒ Time
The time of the last time that Region switch ran an evaluation of the plan.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan.
-
#region ⇒ String
The Amazon Web Services Region for the plan.
-
#warnings ⇒ Array<Types::ResourceWarning>
The current evaluation warnings for the plan.
Instance Attribute Details
#evaluation_state ⇒ String
The evaluation state for the plan.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |
#last_evaluated_version ⇒ String
The version of the last evaluation of the plan.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |
#last_evaluation_time ⇒ Time
The time of the last time that Region switch ran an evaluation of the plan.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a ‘nextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘nextToken` response to request the next page of results.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region for the plan.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |
#warnings ⇒ Array<Types::ResourceWarning>
The current evaluation warnings for the plan.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1048 class GetPlanEvaluationStatusResponse < Struct.new( :plan_arn, :last_evaluation_time, :last_evaluated_version, :region, :evaluation_state, :warnings, :next_token) SENSITIVE = [] include Aws::Structure end |