Class: Aws::ARCRegionswitch::Types::GetPlanExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::GetPlanExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_id ⇒ String
The execution identifier of a plan execution.
-
#max_results ⇒ Integer
The number of objects that you want to return with this call.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan with the execution to retrieve.
Instance Attribute Details
#execution_id ⇒ String
The execution identifier of a plan execution.
1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083 class GetPlanExecutionRequest < Struct.new( :plan_arn, :execution_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The number of objects that you want to return with this call.
1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083 class GetPlanExecutionRequest < Struct.new( :plan_arn, :execution_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a ‘nextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘nextToken` response to request the next page of results.
1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083 class GetPlanExecutionRequest < Struct.new( :plan_arn, :execution_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan with the execution to retrieve.
1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1083 class GetPlanExecutionRequest < Struct.new( :plan_arn, :execution_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |