Class: Aws::ARCRegionswitch::Types::GetPlanExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::GetPlanExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actual_recovery_time ⇒ String
The actual recovery time that Region switch calculates for a plan execution.
-
#comment ⇒ String
A comment included on the plan execution.
-
#end_time ⇒ Time
The time (UTC) when the plan execution ended.
-
#execution_action ⇒ String
The plan execution action.
-
#execution_id ⇒ String
The execution identifier of a plan execution.
-
#execution_region ⇒ String
The Amazon Web Services Region for a plan execution.
-
#execution_state ⇒ String
The plan execution state.
-
#generated_report_details ⇒ Array<Types::GeneratedReport>
Information about the location of a generated report, or the cause of its failure.
-
#mode ⇒ String
The plan execution mode.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
-
#plan ⇒ Types::Plan
The details of the Region switch plan.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan.
-
#recovery_execution_id ⇒ String
The unique identifier of the most recent recovery execution.
-
#start_time ⇒ Time
The time (UTC) when the plan execution started.
-
#step_states ⇒ Array<Types::StepState>
The states of the steps in the plan execution.
-
#updated_at ⇒ Time
The timestamp when the plan execution was last updated.
-
#version ⇒ String
The version for the plan.
Instance Attribute Details
#actual_recovery_time ⇒ String
The actual recovery time that Region switch calculates for a plan execution. Actual recovery time includes the time for the plan to run added to the time elapsed until the application health alarms that you’ve specified are healthy again.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
A comment included on the plan execution.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The time (UTC) when the plan execution ended.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#execution_action ⇒ String
The plan execution action. Valid values are ‘activate`, to activate an Amazon Web Services Region, or `deactivate`, to deactivate a Region.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The execution identifier of a plan execution.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#execution_region ⇒ String
The Amazon Web Services Region for a plan execution.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#execution_state ⇒ String
The plan execution state. Provides the state of a plan execution, for example, In Progress or Paused by Operator.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#generated_report_details ⇒ Array<Types::GeneratedReport>
Information about the location of a generated report, or the cause of its failure.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The plan execution mode. Valid values are ‘graceful`, for graceful executions, or `ungraceful`, for ungraceful executions.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a ‘nextToken` response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s ‘nextToken` response to request the next page of results.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#plan ⇒ Types::Plan
The details of the Region switch plan.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#recovery_execution_id ⇒ String
The unique identifier of the most recent recovery execution. Required when starting a post-recovery execution.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time (UTC) when the plan execution started.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#step_states ⇒ Array<Types::StepState>
The states of the steps in the plan execution.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the plan execution was last updated.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version for the plan.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1175 class GetPlanExecutionResponse < Struct.new( :plan_arn, :execution_id, :version, :updated_at, :comment, :start_time, :end_time, :mode, :execution_state, :execution_action, :execution_region, :recovery_execution_id, :step_states, :plan, :actual_recovery_time, :generated_report_details, :next_token) SENSITIVE = [] include Aws::Structure end |