Class: Aws::ARCRegionswitch::Types::GlobalAuroraConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Configuration for Amazon Aurora global databases used in a Region switch plan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#behaviorString

The behavior for a global database, that is, only allow switchover or also allow failover.

Returns:

  • (String)


1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#cross_account_roleString

The cross account role for the configuration.

Returns:

  • (String)


1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#database_cluster_arnsArray<String>

The database cluster Amazon Resource Names (ARNs) for a global database.

Returns:

  • (Array<String>)


1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#external_idString

The external ID (secret key) for the configuration.

Returns:

  • (String)


1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#global_cluster_identifierString

The global cluster identifier for a global database.

Returns:

  • (String)


1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_minutesInteger

The timeout value specified for the configuration.

Returns:

  • (Integer)


1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end

#ungracefulTypes::GlobalAuroraUngraceful

The settings for ungraceful execution.



1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1280

class GlobalAuroraConfiguration < Struct.new(
  :timeout_minutes,
  :cross_account_role,
  :external_id,
  :behavior,
  :ungraceful,
  :global_cluster_identifier,
  :database_cluster_arns)
  SENSITIVE = []
  include Aws::Structure
end