Class: Aws::ARCRegionswitch::Types::NeptuneGlobalDatabaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::NeptuneGlobalDatabaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Configuration for Amazon Neptune global databases used in a Region switch plan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#behavior ⇒ String
The behavior for a global database, that is, only allow switchover or also allow failover.
-
#cross_account_role ⇒ String
The cross account role for the configuration.
-
#external_id ⇒ String
The external ID (secret key) for the configuration.
-
#global_cluster_identifier ⇒ String
The global cluster identifier for a Neptune global database.
-
#region_database_cluster_arns ⇒ Hash<String,String>
The database cluster Amazon Resource Names (ARNs) for a Neptune global database.
-
#timeout_minutes ⇒ Integer
The timeout value specified for the configuration.
-
#ungraceful ⇒ Types::NeptuneUngraceful
The settings for ungraceful execution.
Instance Attribute Details
#behavior ⇒ String
The behavior for a global database, that is, only allow switchover or also allow failover.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |
#cross_account_role ⇒ String
The cross account role for the configuration.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |
#external_id ⇒ String
The external ID (secret key) for the configuration.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |
#global_cluster_identifier ⇒ String
The global cluster identifier for a Neptune global database.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |
#region_database_cluster_arns ⇒ Hash<String,String>
The database cluster Amazon Resource Names (ARNs) for a Neptune global database.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |
#timeout_minutes ⇒ Integer
The timeout value specified for the configuration.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |
#ungraceful ⇒ Types::NeptuneUngraceful
The settings for ungraceful execution.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 1969 class NeptuneGlobalDatabaseConfiguration < Struct.new( :timeout_minutes, :cross_account_role, :external_id, :behavior, :ungraceful, :global_cluster_identifier, :region_database_cluster_arns) SENSITIVE = [] include Aws::Structure end |