Class: Aws::ARCRegionswitch::Types::ReportOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::ReportOutput
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Note:
ReportOutput is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ReportOutput corresponding to the set member.
The output location or cause of a failure in report generation.
Direct Known Subclasses
Defined Under Namespace
Classes: FailedReportOutput, S3ReportOutput, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failed_report_output ⇒ Types::FailedReportOutput
The details about a failed report generation.
-
#s3_report_output ⇒ Types::S3ReportOutput
Information about a report delivered to Amazon S3.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#failed_report_output ⇒ Types::FailedReportOutput
The details about a failed report generation.
2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2054 class ReportOutput < Struct.new( :s3_report_output, :failed_report_output, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3ReportOutput < ReportOutput; end class FailedReportOutput < ReportOutput; end class Unknown < ReportOutput; end end |
#s3_report_output ⇒ Types::S3ReportOutput
Information about a report delivered to Amazon S3.
2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2054 class ReportOutput < Struct.new( :s3_report_output, :failed_report_output, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3ReportOutput < ReportOutput; end class FailedReportOutput < ReportOutput; end class Unknown < ReportOutput; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2054 2055 2056 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2054 def unknown @unknown end |