Class: Aws::ARCRegionswitch::Types::StartPlanExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::StartPlanExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform.
-
#comment ⇒ String
An optional comment explaining why the plan execution is being started.
-
#latest_version ⇒ String
A boolean value indicating whether to use the latest version of the plan.
-
#mode ⇒ String
The plan execution mode.
-
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan to execute.
-
#recovery_execution_id ⇒ String
The execution identifier of the recovery execution that ran in the opposite region post-recovery is ran in.
-
#target_region ⇒ String
The Amazon Web Services Region to target with this execution.
Instance Attribute Details
#action ⇒ String
The action to perform. Valid values are ‘activate` (to shift traffic to the target Region) or `deactivate` (to shift traffic away from the target Region).
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
An optional comment explaining why the plan execution is being started.
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |
#latest_version ⇒ String
A boolean value indicating whether to use the latest version of the plan. If set to false, you must specify a specific version.
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The plan execution mode. Valid values are ‘graceful`, for starting the execution in graceful mode, or `ungraceful`, for starting the execution in ungraceful mode.
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |
#plan_arn ⇒ String
The Amazon Resource Name (ARN) of the plan to execute.
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |
#recovery_execution_id ⇒ String
The execution identifier of the recovery execution that ran in the opposite region post-recovery is ran in. Required when starting a post-recovery execution.
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |
#target_region ⇒ String
The Amazon Web Services Region to target with this execution. This is the Region that traffic will be shifted to or from, depending on the action.
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2507 class StartPlanExecutionRequest < Struct.new( :plan_arn, :target_region, :action, :mode, :comment, :latest_version, :recovery_execution_id) SENSITIVE = [] include Aws::Structure end |