Class: Aws::ARCRegionswitch::Types::StartPlanExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::StartPlanExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate_region ⇒ String
The Amazon Web Services Region to activate.
-
#deactivate_region ⇒ String
The Amazon Web Services Region to deactivate.
-
#execution_id ⇒ String
The execution identifier of a plan execution.
-
#plan ⇒ String
The details of the Region switch plan.
-
#plan_version ⇒ String
The version of the plan, a unique number generated by Region switch.
Instance Attribute Details
#activate_region ⇒ String
The Amazon Web Services Region to activate.
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2382 class StartPlanExecutionResponse < Struct.new( :execution_id, :plan, :plan_version, :activate_region, :deactivate_region) SENSITIVE = [] include Aws::Structure end |
#deactivate_region ⇒ String
The Amazon Web Services Region to deactivate.
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2382 class StartPlanExecutionResponse < Struct.new( :execution_id, :plan, :plan_version, :activate_region, :deactivate_region) SENSITIVE = [] include Aws::Structure end |
#execution_id ⇒ String
The execution identifier of a plan execution.
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2382 class StartPlanExecutionResponse < Struct.new( :execution_id, :plan, :plan_version, :activate_region, :deactivate_region) SENSITIVE = [] include Aws::Structure end |
#plan ⇒ String
The details of the Region switch plan.
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2382 class StartPlanExecutionResponse < Struct.new( :execution_id, :plan, :plan_version, :activate_region, :deactivate_region) SENSITIVE = [] include Aws::Structure end |
#plan_version ⇒ String
The version of the plan, a unique number generated by Region switch.
2382 2383 2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2382 class StartPlanExecutionResponse < Struct.new( :execution_id, :plan, :plan_version, :activate_region, :deactivate_region) SENSITIVE = [] include Aws::Structure end |