Class: Aws::ARCRegionswitch::Types::Step

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-arcregionswitch/types.rb

Overview

Represents a step in a Region switch plan workflow. Each step performs a specific action during the Region switch process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of a step in a workflow.

Returns:

  • (String)


2413
2414
2415
2416
2417
2418
2419
2420
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413

class Step < Struct.new(
  :name,
  :description,
  :execution_block_configuration,
  :execution_block_type)
  SENSITIVE = []
  include Aws::Structure
end

#execution_block_configurationTypes::ExecutionBlockConfiguration

The configuration for an execution block in a workflow.



2413
2414
2415
2416
2417
2418
2419
2420
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413

class Step < Struct.new(
  :name,
  :description,
  :execution_block_configuration,
  :execution_block_type)
  SENSITIVE = []
  include Aws::Structure
end

#execution_block_typeString

The type of an execution block in a workflow.

Returns:

  • (String)


2413
2414
2415
2416
2417
2418
2419
2420
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413

class Step < Struct.new(
  :name,
  :description,
  :execution_block_configuration,
  :execution_block_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of a step in a workflow.

Returns:

  • (String)


2413
2414
2415
2416
2417
2418
2419
2420
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413

class Step < Struct.new(
  :name,
  :description,
  :execution_block_configuration,
  :execution_block_type)
  SENSITIVE = []
  include Aws::Structure
end