Class: Aws::ARCRegionswitch::Types::Step
- Inherits:
-
Struct
- Object
- Struct
- Aws::ARCRegionswitch::Types::Step
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-arcregionswitch/types.rb
Overview
Represents a step in a Region switch plan workflow. Each step performs a specific action during the Region switch process.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of a step in a workflow.
-
#execution_block_configuration ⇒ Types::ExecutionBlockConfiguration
The configuration for an execution block in a workflow.
-
#execution_block_type ⇒ String
The type of an execution block in a workflow.
-
#name ⇒ String
The name of a step in a workflow.
Instance Attribute Details
#description ⇒ String
The description of a step in a workflow.
2413 2414 2415 2416 2417 2418 2419 2420 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413 class Step < Struct.new( :name, :description, :execution_block_configuration, :execution_block_type) SENSITIVE = [] include Aws::Structure end |
#execution_block_configuration ⇒ Types::ExecutionBlockConfiguration
The configuration for an execution block in a workflow.
2413 2414 2415 2416 2417 2418 2419 2420 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413 class Step < Struct.new( :name, :description, :execution_block_configuration, :execution_block_type) SENSITIVE = [] include Aws::Structure end |
#execution_block_type ⇒ String
The type of an execution block in a workflow.
2413 2414 2415 2416 2417 2418 2419 2420 |
# File 'lib/aws-sdk-arcregionswitch/types.rb', line 2413 class Step < Struct.new( :name, :description, :execution_block_configuration, :execution_block_type) SENSITIVE = [] include Aws::Structure end |