Class: Aws::ARCRegionswitch::Waiters::PlanEvaluationStatusPassed
- Inherits:
-
Object
- Object
- Aws::ARCRegionswitch::Waiters::PlanEvaluationStatusPassed
- Defined in:
- lib/aws-sdk-arcregionswitch/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PlanEvaluationStatusPassed
constructor
A new instance of PlanEvaluationStatusPassed.
-
#wait(params = {}) ⇒ Types::GetPlanEvaluationStatusResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PlanEvaluationStatusPassed
Returns a new instance of PlanEvaluationStatusPassed.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 85 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 5, delay: 30, poller: Aws::Waiters::Poller.new( operation_name: :get_plan_evaluation_status, acceptors: [ { "matcher" => "path", "argument" => "evaluation_state", "state" => "success", "expected" => "passed" }, { "matcher" => "path", "argument" => "evaluation_state", "state" => "failure", "expected" => "actionRequired" }, { "matcher" => "path", "argument" => "evaluation_state", "state" => "retry", "expected" => "pendingEvaluation" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
123 124 125 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 123 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPlanEvaluationStatusResponse
Returns a response object which responds to the following methods:
-
#plan_arn => String
-
#last_evaluation_time => Time
-
#last_evaluated_version => String
-
#region => String
-
#evaluation_state => String
-
#warnings => Array<Types::ResourceWarning>
-
#next_token => String
118 119 120 |
# File 'lib/aws-sdk-arcregionswitch/waiters.rb', line 118 def wait(params = {}) @waiter.wait(client: @client, params: params) end |